@@ -2,6 +2,7 @@ from .forms import Forms
 from .contacts import Contacts
 from .properties import Properties
 from .files import Files
+from .blog import Blog
 import requests
 from delorean import Delorean
 
@@ -45,6 +46,7 @@ class HubSpot:
         self.contacts = Contacts(self)
         self.properties = Properties(self)
         self.files = Files(self)
+        self.blog = Blog(self)
 
     def get_new_token(self):
         """
