@@ -44,7 +44,7 @@ class CMS(HSApi):
             "is_draft": data['draft'],
             "meta_description": data['metaDescription'],
             "meta_keywords": data['metaKeywords'],
-            "name": data['name'],
+            "name": data['title'],
             "post_body": data['body'],
             "post_summary": data['summary'],
             "publish_date": data['publishTimestamp'],
